@@ -1,4 +1,3 @@
-context("test_check_output")
 
 #Test whether the d13C.to.iWUE output is numeric
 test_that("d13C.to.iWUE() returns a numeric value", {
@@ -36,3 +35,8 @@ test_that("d13C.to.diffCaCi() returns a numeric value", {
   expect_type(diffCaCi, "double")
 })
 
+#Test whether the custom.calc output is numeric
+test_that("custom.calc() returns a numeric value", {
+  D13C <- custom.calc(-26, -8)
+  expect_type(D13C, "double")
+})
